package gs.config

import gs.config.audit.ConfigSource

/** Interface for loading configuration values.
  *
  * This interface is **not** intended to be used with sensitive information. Do
  * not use this interface for loading passwords, encryption keys, or any other
  * sensitive information.
  */
trait Configuration[F[_]]:
  /** Retrieve the value for the specified key.
    *
    * @param key
    *   The key which defines the piece of configuration.
    * @return
    *   The value, or an error if no value can be retrieved.
    */
  def getValue[A: Configurable](key: ConfigKey[A]): F[Either[ConfigError, A]]

  /** @return
    *   The backing source for this configuration.
    */
  def source: ConfigSource
